@@ -27,6 +27,7 @@ if TYPE_CHECKING:
     from pytest_mock import MockerFixture
     from tomlkit import TOMLDocument
 
+    from poetry.config.config import Config
     from poetry.poetry import Poetry
     from poetry.utils.env import MockEnv
     from poetry.utils.env import VirtualEnv
@@ -37,6 +38,13 @@ if TYPE_CHECKING:
     from tests.types import ProjectFactory
 
 
+@pytest.fixture(autouse=True)
+def config(config: Config) -> Config:
+    # Disable parallel installs to get reproducible output.
+    config.merge({"installer": {"parallel": False}})
+    return config
+
+
 @pytest.fixture
 def poetry_with_up_to_date_lockfile(
     project_factory: ProjectFactory, fixture_dir: FixtureDirGetter
@@ -101,6 +109,29 @@ Writing lock file
     assert content["dependencies"]["cachy"] == "^0.2.0"
 
 
+def test_add_non_package_mode_no_name(
+    repo: TestRepository,
+    project_factory: ProjectFactory,
+    command_tester_factory: CommandTesterFactory,
+) -> None:
+    repo.add_package(get_package("cachy", "0.2.0"))
+
+    poetry = project_factory(
+        name="foobar", pyproject_content="[tool.poetry]\npackage-mode = false\n"
+    )
+    tester = command_tester_factory("add", poetry=poetry)
+    tester.execute("cachy")
+
+    assert isinstance(tester.command, InstallerCommand)
+    assert tester.command.installer.executor.installations_count == 1
+
+    pyproject: dict[str, Any] = poetry.file.read()
+    content = pyproject["tool"]["poetry"]
+
+    assert "cachy" in content["dependencies"]
+    assert content["dependencies"]["cachy"] == "^0.2.0"
+
+
 def test_add_replace_by_constraint(
     app: PoetryTestApplication, repo: TestRepository, tester: CommandTester
 ) -> None:
